@@ -2,7 +2,7 @@
 //!
 
 /// Give you an easy interaction with an executable launched as a child process.
-pub mod process;
+pub mod connection;
 
 /// Retrive info from your elf binary.
 pub mod pwn;
